"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schema_validator_1 = require("../utils/schema-validator");
const debug_1 = require("../utils/debug");
const problems_1 = require("../types/problems");
const debug = debug_1.debug(__filename);
exports.getSeverity = (config) => {
    let configuredSeverity = null;
    if (typeof config === 'string') {
        configuredSeverity = problems_1.Severity[config];
    }
    else if (typeof config === 'number') {
        configuredSeverity = config;
    }
    else if (Array.isArray(config)) {
        configuredSeverity = exports.getSeverity(config[0]);
    }
    if (configuredSeverity !== null && configuredSeverity >= 0 && configuredSeverity <= 2) {
        return configuredSeverity;
    }
    return null;
};
const validateHint = (schema, hintConfig) => {
    return schema_validator_1.validate(schema, hintConfig).valid;
};
exports.validate = (meta, config, hintId) => {
    debug(`Validating hint ${hintId}`);
    if (!Array.isArray(config) && typeof config === 'object') {
        return false;
    }
    const configuredSeverity = exports.getSeverity(config);
    if (configuredSeverity === null) {
        throw new Error(`Invalid severity configured for ${hintId}`);
    }
    const schema = meta.schema;
    if (!Array.isArray(config) || (Array.isArray(schema) && schema.length === 0)) {
        return true;
    }
    if (Array.isArray(schema)) {
        if (config.length === 1) {
            return true;
        }
        return schema.some((sch) => {
            return validateHint(sch, config[1]);
        });
    }
    return validateHint(meta.schema, config[1]);
};
